@@ -1,14 +1,14 @@
-# Copyrights 2003-2020 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2003-2022 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
+# Pod stripped from pm file by OODoc 2.03.
 # This code is part of distribution User-Identity.  Meta-POD processed with
 # OODoc into POD and HTML manual-pages.  See README.md
 # Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Identity;
 use vars '$VERSION';
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 use base 'User::Identity::Item';
 
@@ -46,11 +46,8 @@ sub from($)
     return $other if $other->isa(__PACKAGE__);
 
     if($other->isa('Mail::Address'))
-    {   return $class->new
-          ( phrase  => $other->phrase
-          , address => $other->address
-          , comment => $other->comment
-          , @_);
+    {   # Mail::Address is far to lazy
+        return $class->parse($other->format);
     }
 
     if($other->isa('User::Identity'))
