@@ -1,11 +1,20 @@
+# Copyrights 2003-2022 by [Mark Overmeer <markov@cpan.org>].
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 2.03.
+# This code is part of distribution User-Identity.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package User::Identity::Archive::Plain;
 use vars '$VERSION';
-$VERSION = '0.90';
+$VERSION = '1.01';
+
 use base 'User::Identity::Archive';
 
 use strict;
 use warnings;
+
 use Carp;
 
 
@@ -82,6 +91,7 @@ sub from($@)
 
     while(my $starter = $self->_get_line)
     {   $self->_accept_line;
+#warn "$verbose: $starter\n";
         my $indent = $self->_indentation($starter);
 
         print "  adding $starter" if $verbose > 1;
@@ -214,7 +224,8 @@ sub _collectItem($$)
 #warn "$class NAME=$name";
     my $warn     = 0;
     my $warn_sub = $SIG{__WARN__};
-    $SIG{__WARN__} = sub {$warn++; $warn_sub ? $warn_sub->(@_) : print STDERR @_};
+    $SIG{__WARN__}
+       = sub {$warn++; $warn_sub ? $warn_sub->(@_) : print STDERR @_};
 
     my $item = $class->new(name => $name, @fields);
     $SIG{__WARN__} = $warn_sub;
@@ -224,6 +235,7 @@ sub _collectItem($$)
         $linenr -= 1;
         warn "  found in $source around line $linenr\n";
     }
+#warn $_->type foreach @items;
 
     $item->add($_->type => $_) foreach @items;
     $item;
